@@ -134,7 +134,7 @@ def RetrieveData(Date, args):
         
             # Reproject the MODIS product to epsg_to
             epsg_to ='4326'
-            name_reprojected = RC.reproject_MODIS(name_collect, epsg_to)
+            name_reprojected = RC.reproject_MODIS(name_collect, epsg_to, resolution = 0.005)
         
             # Clip the data to the users extend
             data, geo, proj = RC.clip_data(name_reprojected, latlim, lonlim)
@@ -179,7 +179,7 @@ def Collect_data(TilesHorizontal,TilesVertical,Date,output_folder, hdf_library):
             countX=Horizontal - TilesHorizontal[0] + 1
 
             # Download the MODIS NDVI data
-            url = 'https://e4ftl01.cr.usgs.gov/MOTA/MCD43A3.006/' + Date.strftime('%Y') + '.' + Date.strftime('%m') + '.' + Date.strftime('%d') + '/'
+            url = 'https://e4ftl01.cr.usgs.gov/MOTA/MCD43A3.061/' + Date.strftime('%Y') + '.' + Date.strftime('%m') + '.' + Date.strftime('%d') + '/'
 
 		      # Reset the begin parameters for downloading
             downloaded = 0
