@@ -158,7 +158,8 @@ def RetrieveData(Date, args):
         
             # Reproject the MODIS product to epsg_to
             epsg_to ='4326'
-            name_reprojected = RC.reproject_MODIS(name_collect, epsg_to)
+            resolution = 0.01
+            name_reprojected = RC.reproject_MODIS(name_collect, epsg_to, resolution = resolution)
         
             # Clip the data to the users extend
             data, geo, proj = RC.clip_data(name_reprojected, latlim, lonlim)
@@ -298,9 +299,9 @@ def Collect_data(TilesHorizontal,TilesVertical,Date,output_folder, TimeStep, hdf
 
             # Download the MODIS NDVI data
             if TimeStep == 8:
-                url = 'https://e4ftl01.cr.usgs.gov/MOLT/MOD11A2.006/' + Date.strftime('%Y') + '.' + Date.strftime('%m') + '.' + Date.strftime('%d') + '/'
+                url = 'https://e4ftl01.cr.usgs.gov/MOLT/MOD11A2.061/' + Date.strftime('%Y') + '.' + Date.strftime('%m') + '.' + Date.strftime('%d') + '/'
             if TimeStep == 1:
-                url = 'https://e4ftl01.cr.usgs.gov/MOLT/MOD11A1.006/' + Date.strftime('%Y') + '.' + Date.strftime('%m') + '.' + Date.strftime('%d') + '/'
+                url = 'https://e4ftl01.cr.usgs.gov/MOLT/MOD11A1.061/' + Date.strftime('%Y') + '.' + Date.strftime('%m') + '.' + Date.strftime('%d') + '/'
 
 		    # Reset the begin parameters for downloading
             downloaded = 0
