@@ -23,7 +23,7 @@ def main(Dir, Startdate, Enddate, latlim, lonlim, Time = '', GMT_Offset = 0, Wai
     """
     print('\nDownload 15min short downward surface radiation from MSGCPP for period %s till %s' %(Startdate, Enddate))
     
-    DownloadData(Dir, Startdate, Enddate, latlim, lonlim, Time, GMT_Offset, Waitbar)
+    DownloadData(Dir, Startdate, Enddate, latlim, lonlim, Time, GMT_Offset, Waitbar, Type = "SDS")
 
 if __name__ == '__main__':
     main(sys.argv)
\ No newline at end of file
